@@ -99,7 +99,9 @@ arma::mat hdpGLM_get_theta_active(arma::mat theta, arma::colvec Z, arma::colvec
     arma::uvec     idx_j = find(C == j);   
     arma::colvec  Zjstar = unique(Z(idx_j));
     for(int i = 0; i < int(Zjstar.n_rows); i++){
-      int idx_k_active_in_j = conv_to<int>::from( find(theta.col(0) == Zjstar(i) && theta.col(1) == j) ); 
+      // int idx_k_active_in_j = conv_to<int>::from( find(theta.col(0) == Zjstar(i) && theta.col(1) == j) ); 
+      int idx_k_active_in_j = arma::as_scalar( find(theta.col(0) == Zjstar(i) && theta.col(1) == j) );
+
       theta_new.row(count) = theta.row(idx_k_active_in_j);
       count+=1;
     }
